@@ -3,16 +3,13 @@
 
 Provides one class: Lamination. '''
 
+from math import inf
+from queue import Queue
 import heapq
-try:
-    from Queue import Queue
-except ImportError:
-    from queue import Queue
 
 import flipper
 from flipper.kernel.decorators import memoize  # Special import needed for decorating.
 
-INFTY = float('inf')
 HASH_DENOMINATOR = 30
 
 class Lamination:
@@ -154,7 +151,7 @@ class Lamination:
         
         # We'll try to preserve as much of the structure as possible to try to reduce hash collisions.
         # In this version we'll store the sorted, cyclically ordered, triangles.
-        triples = [tuple([L[edge.index] for edge in triangle]) for triangle in self.triangulation]
+        triples = [tuple(L[edge.index] for edge in triangle) for triangle in self.triangulation]
         return tuple(sorted([min(triple[i:] + triple[:i] for i in range(len(triple))) for triple in triples]))
     
     def weight(self):
@@ -202,7 +199,7 @@ class Lamination:
         def weight_change(lamination, edge_index):
             ''' Return how much the weight would change by if this flip was done. '''
             
-            if lamination(edge_index) == 0 or not lamination.triangulation.is_flippable(edge_index): return INFTY
+            if lamination(edge_index) == 0 or not lamination.triangulation.is_flippable(edge_index): return inf
             a, b, c, d = lamination.triangulation.square_about_edge(edge_index)
             return max(lamination(a) + lamination(c), lamination(b) + lamination(d)) - 2 * lamination(edge_index)
         
@@ -622,8 +619,8 @@ class Lamination:
                         # Need to rebuild the heap as indices no longer correspond.
                         weights_heap = [flip_first((weight, index)) for index, weight in enumerate(lamination)]
                         heapq.heapify(weights_heap)
-                    except flipper.AssumptionError:
-                        raise flipper.AssumptionError('Lamination is not filling.')
+                    except flipper.AssumptionError as err:
+                        raise flipper.AssumptionError('Lamination is not filling.') from err
                 else:
                     # Add the new edge weight back into the heap.
                     heapq.heappush(weights_heap, flip_first((lamination(flip_index), flip_index)))
