@@ -8,18 +8,13 @@ Provides five classes: Vertex, Edge, Triangle, Corner and Triangulation.
     A Triangulation is a collection of Triangles. '''
 
 from itertools import groupby
-from math import log
+from math import log, inf
+from queue import Queue
 from random import choice
 import string
-try:
-    from Queue import Queue
-except ImportError:
-    from queue import Queue
 
 import flipper
 
-INFTY = float('inf')
-
 def norm(value):
     ''' A map taking an edges label to its index.
     
@@ -254,8 +249,8 @@ class Triangulation:
             for i in range(len(corner_class)-1):
                 try:
                     ordered_class[i+1] = lookup[~ordered_class[i].edges[1]]
-                except KeyError:
-                    raise ValueError('Corners do not close up about vertex.')
+                except KeyError as err:
+                    raise ValueError('Corners do not close up about vertex.') from err
             
             if ordered_class[0].edges[2] != ~ordered_class[-1].edges[1]:
                 raise ValueError('Corners do not close up about vertex.')
@@ -437,8 +432,8 @@ class Triangulation:
         
         try:
             values = [char_lookup[letter] for letter in signature]
-        except KeyError:
-            raise ValueError('Signature must be a string matching [a-zA-Z0-9+-]*')
+        except KeyError as err:
+            raise ValueError('Signature must be a string matching [a-zA-Z0-9+-]*') from err
         
         if values[0] < 63:
             num_chars = 1
@@ -490,8 +485,8 @@ class Triangulation:
                             permutation_index += 1
                         else:
                             raise ValueError('Each gluing must be type 0, 1 or 2.')
-                    except IndexError:
-                        raise ValueError('String does not correspond to a isomorphism signature.')
+                    except IndexError as err:
+                        raise ValueError('String does not correspond to a isomorphism signature.') from err
                     type_index += 1
                     
                     edge_labels[i][j] = zeta
@@ -598,7 +593,7 @@ class Triangulation:
         be used to generate signatures relative to a fixed boundary by specify
         an edge on that boundary (and True) as the only starting point. '''
         
-        best = ([INFTY], [INFTY], [INFTY])
+        best = ([inf], [inf], [inf])
         skip = set() if skip is None else set(skip)
         
         perm_inverse = flipper.kernel.permutation.PERM3_INVERSE
